==> tracebook-0.1.3.tar.gz: tracebook-0.1.3/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="tracebook",
    version="0.1.3",
    description="A comprehensive code bookkeeping package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=["book-keeping", "visualizer"],
    author="Sujal Choudhari",
    author_email="hello@sujal.xyz",
    packages=find_packages(include=["tracebook", "tracebook.*"]),
    install_requires=[
        "blinker==1.8.2",
        "certifi==2024.7.4",
        "charset-normalizer==3.3.2",
        "click==8.1.7",
        "colorama==0.4.6",
        "dash==2.17.1",
        "dash-bootstrap-components==1.6.0",
        "dash-core-components==2.0.0",
        "dash-html-components==2.0.0",
        "dash-table==5.0.0",
        "docutils==0.21.2",
        "Flask==3.0.3",
        "idna==3.7",
        "importlib_metadata==8.2.0",
        "itsdangerous==2.2.0",
        "jaraco.classes==3.4.0",
        "jaraco.context==5.3.0",
        "jaraco.functools==4.0.2",
        "Jinja2==3.1.4",
        "keyring==25.3.0",
        "markdown-it-py==3.0.0",
        "MarkupSafe==2.1.5",
        "mdurl==0.1.2",
        "more-itertools==10.4.0",
        "nest-asyncio==1.6.0",
        "nh3==0.2.18",
        "packaging==24.1",
        "pkginfo==1.10.0",
        "plotly==5.23.0",
        "psutil==6.0.0",
        "Pygments==2.18.0",
        "pywin32-ctypes==0.2.2",
        "readme_renderer==44.0",
        "requests==2.32.3",
        "requests-toolbelt==1.0.0",
        "retrying==1.3.4",
        "rfc3986==2.0.0",
        "rich==13.7.1",
        "setuptools==72.1.0",
        "six==1.16.0",
        "tenacity==9.0.0",
        "typing_extensions==4.12.2",
        "urllib3==2.2.2",
        "watchdog==4.0.2",
        "Werkzeug==3.0.3",
        "wheel==0.44.0",
        "zipp==3.20.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.8",
    ],
    python_requires=">=3.6",
)

==> tracebook-0.1.4.tar.gz: tracebook-0.1.4/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="tracebook",
    version="0.1.4",
    description="A comprehensive code bookkeeping package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=["book-keeping", "visualizer"],
    author="Sujal Choudhari",
    author_email="hello@sujal.xyz",
    packages=find_packages(),
    install_requires=[
        "blinker==1.8.2",
        "certifi==2024.7.4",
        "charset-normalizer==3.3.2",
        "click==8.1.7",
        "colorama==0.4.6",
        "dash==2.17.1",
        "dash-bootstrap-components==1.6.0",
        "dash-core-components==2.0.0",
        "dash-html-components==2.0.0",
        "dash-table==5.0.0",
        "docutils==0.21.2",
        "Flask==3.0.3",
        "idna==3.7",
        "importlib_metadata==8.2.0",
        "itsdangerous==2.2.0",
        "jaraco.classes==3.4.0",
        "jaraco.context==5.3.0",
        "jaraco.functools==4.0.2",
        "Jinja2==3.1.4",
        "keyring==25.3.0",
        "markdown-it-py==3.0.0",
        "MarkupSafe==2.1.5",
        "mdurl==0.1.2",
        "more-itertools==10.4.0",
        "nest-asyncio==1.6.0",
        "nh3==0.2.18",
        "packaging==24.1",
        "pkginfo==1.10.0",
        "plotly==5.23.0",
        "psutil==6.0.0",
        "Pygments==2.18.0",
        "pywin32-ctypes==0.2.2",
        "readme_renderer==44.0",
        "requests==2.32.3",
        "requests-toolbelt==1.0.0",
        "retrying==1.3.4",
        "rfc3986==2.0.0",
        "rich==13.7.1",
        "setuptools==72.1.0",
        "six==1.16.0",
        "tenacity==9.0.0",
        "typing_extensions==4.12.2",
        "urllib3==2.2.2",
        "watchdog==4.0.2",
        "Werkzeug==3.0.3",
        "wheel==0.44.0",
        "zipp==3.20.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.8",
    ],
    python_requires=">=3.6",
)
